/********************************************************************/
/*                                                                  */
/*            L   I  QQ  U U I DD    W   W  A  RR    555            */
/*            L   I Q  Q U U I D D   W   W A A R R   5              */
/*            L   I Q  Q U U I D D   W W W AAA RR    55             */
/*            L   I Q Q  U U I D D   WW WW A A R R     5            */
/*            LLL I  Q Q  U  I DD    W   W A A R R   55             */
/*                                                                  */
/*                             b                                    */
/*                             bb  y y                              */
/*                             b b yyy                              */
/*                             bb    y                              */
/*                                 yy                               */
/*                                                                  */
/*                     U U       FFF  O   O  TTT                    */
/*                     U U       F   O O O O  T                     */
/*                     U U TIRET FF  O O O O  T                     */
/*                     U U       F   O O O O  T                     */
/*                      U        F    O   O   T                     */
/*                                                                  */
/********************************************************************/

/*****************************************************************************/
/* Liquid War is a unique multiplayer wargame                                */
/* Copyright (C) 1998-2002 Christian Mauduit                                 */
/*                                                                           */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software               */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
/*                                                                           */
/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
/* Contact author      : ufoot@ufoot.org                                     */
/*****************************************************************************/

/********************************************************************/
/* nom           : mouse.h                                          */
/* contenu       : gestion de la souris                             */
/* date de modif : 3 mai 98                                         */
/********************************************************************/

#ifndef LIQUID_WAR_INCLUDE_MOUSE
#define LIQUID_WAR_INCLUDE_MOUSE

/*==================================================================*/
/* includes                                                         */
/*==================================================================*/

/*==================================================================*/
/* variables globales                                               */
/*==================================================================*/

#define KEY_MOUSE_UP      124
#define KEY_MOUSE_RIGHT   125
#define KEY_MOUSE_DOWN    126
#define KEY_MOUSE_LEFT    127

extern int MOUSE_CONTROL_REF_X;
extern int MOUSE_CONTROL_REF_Y;
extern int MOUSE_CONTROL_UP;
extern int MOUSE_CONTROL_RIGHT;
extern int MOUSE_CONTROL_DOWN;
extern int MOUSE_CONTROL_LEFT;

/*==================================================================*/
/* fonctions globales                                               */
/*==================================================================*/

void lw_mouse_update_control (void);
void lw_mouse_reset_control (void);
void lw_mouse_update_show_hide(void);
void lw_mouse_show (void);
void lw_mouse_hide (void);

#endif
